import { AtModal, AtModalContent } from "taro-ui";
import { View, Image, Text, Button, Input } from "@tarojs/components";
import "./index.less";
import { useState, useEffect } from "react";

// 分享模态框组件
export default function shareModal(props) {
  // 解构props,获取必要参数
  const { isOpened, onClose, product, onShareTitleChange } = props;
  // 分享标题状态管理
  const [shareTitle, setShareTitle] = useState('');

  // 当商品信息更新时,设置分享标题
  useEffect(() => {
    if (product?.item_title) {
      setShareTitle(product.item_title);
    }
  }, [product]);

  // 监听模态框开关状态
  // 关闭时清空标题,打开时设置为商品标题
  useEffect(() => {
    if (!isOpened) {
      setShareTitle('');
    } else {
      setShareTitle(product.item_title);
    }
  }, [isOpened]);

  // 处理输入框内容变化
  const handleInputChange = (e) => {
    const newTitle = e.detail.value;
    setShareTitle(newTitle);
    onShareTitleChange?.(newTitle);
  }

  return (
    <View className="share-modal">
      <AtModal isOpened={isOpened} closeOnClickOverlay={true} onClose={onClose}>
        <AtModalContent>
          {product && (
          <View className="container">
            {/* 商品图片展示 */}
            <Image className="product-image" src={product.image_url} mode="aspectFill" />
            {/* 商品标题展示 */}
            <View className="title">{product.item_title}</View>
            {/* 分享标题输入框 */}
            <Input onInput={handleInputChange} className="input" value={shareTitle} />
            {/* 分享按钮 */}
            <Button openType="share" onClick={onClose}>
              <View className="share-button">
                分享
              </View>
            </Button>
          </View>
        )}
        </AtModalContent>
      </AtModal>
    </View>
  );
}
